using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;

namespace GridSample
{

	public class SwitchColumn : IGGridViewColumnDefinition
	{
		public SwitchColumn(String key) : base(key)
		{
		}

		public override IGGridViewCell CreateCell (IGGridView gridView, IGCellPath path, IGGridViewDataSourceHelper dataSource)
		{
			SwitchCell cell = (SwitchCell)gridView.DequeueReusableCell ("Bc");

			if (cell == null)
				cell = new SwitchCell ("Bc");


			return cell;
		}
	}

	public class SwitchCell : IGGridViewCell
	{
		UISwitch _switch;

		public SwitchCell (String identifier) : base (identifier)
		{
			_switch = new UISwitch ();

			_switch.AddTarget (this, new MonoTouch.ObjCRuntime.Selector ("valueChanged"), UIControlEvent.ValueChanged);
			this.AddSubview (_switch);
		}

		[Export("valueChanged")]
		public void OnValueChanged()
		{

		}

		[Export("selectGesture:")]
		public void overrideSelectGesture(UIGestureRecognizer gesture)
		{
			// Do Nothing
		}

		public override void SetupSize (SizeF size)
		{
			base.SetupSize (size);

			_switch.SizeToFit ();

			_switch.Frame = new RectangleF (size.Width/2 - _switch.Bounds.Size.Width/2, size.Height/2 - _switch.Bounds.Size.Height/2, _switch.Bounds.Size.Width, _switch.Bounds.Size.Height);
		}

	}

	public partial class GridSampleViewController : UIViewController
	{
		public GridSampleViewController () : base ("GridSampleViewController", null)
		{

		
		}


		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			IGGridView grid = new IGGridView (this.View.Bounds, IGGridViewStyle.IGGridViewStyleDefault);
			grid.AutoresizingMask = UIViewAutoresizing.FlexibleDimensions;
			this.View.AddSubview (grid);
	


			IGGridViewDataSourceHelper dsh = new IGGridViewDataSourceHelper ();

			dsh.ColumnDefinitions.Add (new SwitchColumn ("temp"));
			dsh.Data = IGSalesmanItem.GenerateData (100).ToArray ();
			grid.DataSource = dsh;

		

		}
	}
}

